@@ -32,17 +32,17 @@ class CameraType;
 
 class Plugin_KameraKlient : public KIPI::Plugin {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     Plugin_KameraKlient(TQObject *parent, const char* name, const TQStringList& args);
     ~Plugin_KameraKlient();
 	virtual void setup(TQWidget* widget);
-    virtual KIPI::Category category(KAction*) const;
+    virtual KIPI::Category category(TDEAction*) const;
     TQString id() const {
 		return TQString::fromLatin1("kameraklient");
     }
-	KAction* mKameraKlientAction;
+	TDEAction* mKameraKlientAction;
 
 protected slots:
     void slotActivate();
