@@ -27,8 +27,8 @@
 
 #include <kdialogbase.h>
 
-class KListView;
-class KURL::List;
+class TDEListView;
+class KURL;
 
 namespace KIPISendimagesPlugin
 {
@@ -36,7 +36,7 @@ namespace KIPISendimagesPlugin
 class listImagesErrorDialog : public KDialogBase
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 
@@ -48,7 +48,7 @@ public:
 
 private:
 
-    KListView *m_listFiles;
+    TDEListView *m_listFiles;
 };
 
 }  // NameSpace KIPISendimagesPlugin
